Module oauth

Module oauth 

Re-exports

pub use pending::PendingAuthorization;
pub use pkce::Pkce;

Modules

authorize
pending
pkce
revoke
test
token

Structs

AccessToken
An access token obtained by exchanging an authorization code.
Token

Type Aliases

TestResults
Maps each tested token to its details, or None if the token is invalid.